Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetIntOrDefault ¶
GetIntOrDefault return value as string or if value is empty or not string return defaultValue
func GetJSONParameters ¶
func GetJSONParameters(body io.ReadCloser, out interface{}) error
GetJSONParameters ...
func RespondWithJSON ¶
func RespondWithJSON(w http.ResponseWriter, code int, payload interface{})
RespondWithJSON prepare response as json with status code
func ResponseBadRequestError ¶
func ResponseBadRequestError(w http.ResponseWriter, err error)
ResponseBadRequestError return response with error and bad request status
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.